pub struct MockPoliciesApi {
PoliciesApi_expectations: MockPoliciesApi_PoliciesApi,
}Fields
PoliciesApi_expectations: MockPoliciesApi_PoliciesApiImplementations
Sourceimpl MockPoliciesApi
impl MockPoliciesApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockPoliciesApi
impl MockPoliciesApi
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_get_by_token(&mut self) -> &mut Expectation
pub fn expect_get_by_token(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_by_token method
Sourcepub fn expect_get_master_password_policy(&mut self) -> &mut Expectation
pub fn expect_get_master_password_policy(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_master_password_policy method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method